# Changelog for plugin *ce-ui*

## 1.5.1 (2024-01-21)

- ENH: Added alert for failing uploads
- BUG: Fixed search (#45)
- BUG: Fixed display of alerts
- MAINT: Nicer placeholders while loading dataset

## 1.5.0 (2024-01-20)

- MAINT: Split user interface module from main TopoBank
- MAINT: Fix Boostrap style on close button of modal windows
- MAINT: Reorganized layout of left control buttons
- MAINT: Enforcing PEP-8 style